==> kdebindings-3.0.1-i386-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libdcopc.so )
( cd opt/kde/lib ; ln -sf libdcopc.so.1.0.0 libdcopc.so )
( cd opt/kde/lib ; rm -rf libdcopc.so.1 )
( cd opt/kde/lib ; ln -sf libdcopc.so.1.0.0 libdcopc.so.1 )
( cd opt/kde/lib ; rm -rf libgtkxparts.so )
( cd opt/kde/lib ; ln -sf libgtkxparts.so.0.0.0 libgtkxparts.so )
( cd opt/kde/lib ; rm -rf libgtkxparts.so.0 )
( cd opt/kde/lib ; ln -sf libgtkxparts.so.0.0.0 libgtkxparts.so.0 )
( cd opt/kde/lib ; rm -rf libkdec.so )
( cd opt/kde/lib ; ln -sf libkdec.so.1.0.0 libkdec.so )
( cd opt/kde/lib ; rm -rf libkdec.so.1 )
( cd opt/kde/lib ; ln -sf libkdec.so.1.0.0 libkdec.so.1 )
( cd opt/kde/lib ; rm -rf libkdexparts.so )
( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so )
( cd opt/kde/lib ; rm -rf libkdexparts.so.1 )
( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so.1 )
( cd opt/kde/lib ; rm -rf libkmozillapart.so )
( cd opt/kde/lib ; ln -sf libkmozillapart.so.0.0.0 libkmozillapart.so )
( cd opt/kde/lib ; rm -rf libkmozillapart.so.0 )
( cd opt/kde/lib ; ln -sf libkmozillapart.so.0.0.0 libkmozillapart.so.0 )
( cd opt/kde/lib ; rm -rf libqtc.so )
( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so )
( cd opt/kde/lib ; rm -rf libqtc.so.1 )
( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so.1 )
( cd opt/kde/lib ; rm -rf libxp_notepadpart.so )
( cd opt/kde/lib ; ln -sf libxp_notepadpart.so.0.0.0 libxp_notepadpart.so )
( cd opt/kde/lib ; rm -rf libxp_notepadpart.so.0 )
( cd opt/kde/lib ; ln -sf libxp_notepadpart.so.0.0.0 libxp_notepadpart.so.0 )

==> kdebindings-3.1-i386-2.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libdcopc.so )
( cd opt/kde/lib ; ln -sf libdcopc.so.1.0.0 libdcopc.so )
( cd opt/kde/lib ; rm -rf libdcopc.so.1 )
( cd opt/kde/lib ; ln -sf libdcopc.so.1.0.0 libdcopc.so.1 )
( cd opt/kde/lib ; rm -rf libxp_notepadpart.so )
( cd opt/kde/lib ; ln -sf libxp_notepadpart.so.0.0.0 libxp_notepadpart.so )
( cd opt/kde/lib ; rm -rf libqtc.so.1 )
( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so.1 )
( cd opt/kde/lib ; rm -rf libqtc.so )
( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so )
( cd opt/kde/lib ; rm -rf libkdexparts.so.1 )
( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so.1 )
( cd opt/kde/lib ; rm -rf libkjsembed.so )
( cd opt/kde/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so )
( cd opt/kde/lib ; rm -rf libsmokeqt.so.1 )
( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.0.0 libsmokeqt.so.1 )
( cd opt/kde/lib ; rm -rf libkjsembed.so.1 )
( cd opt/kde/lib ; ln -sf libkjsembed.so.1.0.0 libkjsembed.so.1 )
( cd opt/kde/lib ; rm -rf libgtkxparts.so )
( cd opt/kde/lib ; ln -sf libgtkxparts.so.0.0.0 libgtkxparts.so )
( cd opt/kde/lib ; rm -rf libxp_notepadpart.so.0 )
( cd opt/kde/lib ; ln -sf libxp_notepadpart.so.0.0.0 libxp_notepadpart.so.0 )
( cd opt/kde/lib ; rm -rf libkdexparts.so )
( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so )
( cd opt/kde/lib ; rm -rf libgtkxparts.so.0 )
( cd opt/kde/lib ; ln -sf libgtkxparts.so.0.0.0 libgtkxparts.so.0 )
( cd opt/kde/lib ; rm -rf libsmokeqt.so )
( cd opt/kde/lib ; ln -sf libsmokeqt.so.1.0.0 libsmokeqt.so )
